Modal

Enum Modal 

pub enum Modal {
    Appearance(i64),
    ConfirmErase(Uuid, i64),
    ConfirmDelete(Uuid, i64),
    CreateWizard(CreateWizard),
    PrivacyWizard(PrivacyWizard),
    LaunchApp(LaunchAppPrompt),
    Inspector(Uuid),
    OpenUrl(OpenUrlPrompt),
    CommandPalette(CommandPalette),
    Help,
}

Variants



Appearance(i64)

Selected index: 0 = Light, 1 = Dark.



ConfirmErase(Uuid, i64)

Selected index: 0 = Yes, 1 = No.



ConfirmDelete(Uuid, i64)

Selected index: 0 = Yes, 1 = No.



CreateWizard(CreateWizard)



PrivacyWizard(PrivacyWizard)



LaunchApp(LaunchAppPrompt)



Inspector(Uuid)



OpenUrl(OpenUrlPrompt)



CommandPalette(CommandPalette)



Help

Implementations

Source

impl Modal

pub fn referenced_simulator(&self) -> Option<Uuid>

Some modals reference a specific simulator by UDID. If that sim disappears between the modal opening and the next refresh, the reducer drops the modal.